@@ -17,16 +17,13 @@ QmlLoader::QmlLoader():
         QDeclarativeView()       
 {
     
-    
+#ifndef Q_WS_MAC
     QGLFormat format = QGLFormat::defaultFormat();
     format.setSampleBuffers(false);
-    QGLWidget *glWidget = new QGLWidget(format);
+    QGLWidget *glWidget = new QGLWidget();//(format);
     glWidget->setAutoFillBackground(false);
     setViewport(glWidget);
-    
-    
-
-    connect(engine(),SIGNAL(quit()),qApp,SLOT(quit()));
+#endif
     
     // Setup the C++ side for providing data for QML
     m_flickrManager = new FlickrManager();    
@@ -42,6 +39,11 @@ QmlLoader::QmlLoader():
     m_flickrManager->activate();
 }
 
+QmlLoader::~QmlLoader()
+{
+    delete m_flickrManager;
+    m_flickrManager = 0;
+}
 
 void QmlLoader::minimize()
 {
